<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package    WordPress
 * @subpackage Martian
 * @since      1.0
 */

if ( ! function_exists( 'martian_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function martian_posted_on() {

		// Get the author name; wrap it in a link.
		$byline = sprintf(
		/* translators: %s: post author */
			__( 'by %s', 'martian' ),
			'<span class="author vcard">' . get_the_author_posts_link() . '</span>'
		);

		// Finally, let's write all of this to the page.
		echo '<span class="posted-on">' . martian_time_link() . '</span><span class="byline"> ' . $byline . '</span>';
	}
endif;


if ( ! function_exists( 'martian_time_link' ) ) :
	/**
	 * Gets a nicely formatted string for the published date.
	 */
	function martian_time_link() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			get_the_date( DATE_W3C ),
			'<span>' . get_the_date() . '</span>',
			get_the_modified_date( DATE_W3C ),
			get_the_modified_date()
		);

		// Wrap the time string in a link, and preface it with 'Posted on'.
		return sprintf(
		/* translators: %s: post date */
			__( '<span class="screen-reader-text">Posted on</span> %s', 'martian' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);
	}
endif;

if ( ! function_exists( 'martian_time_link_full' ) ) :
	/**
	 * Gets a nicely formatted string for the published date.
	 */
	function martian_time_link_full() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			get_the_date( DATE_W3C ),
			get_the_date( 'd M y' ),
			get_the_modified_date( DATE_W3C ),
			get_the_modified_date()
		);

		// Wrap the time string in a link, and preface it with 'Posted on'.
		return sprintf(
		/* translators: %s: post date */
			__( '<span class="screen-reader-text">Posted on</span> %s', 'martian' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);
	}
endif;


if ( ! function_exists( 'martian_entry_meta' ) ) :
	/**
	 * Prints HTML with meta information for the byline categories and comments.
	 */
	function martian_entry_meta() {

		/* translators: used between list items, there is a space after the comma */
		$separate_meta = __( ', ', 'martian' );

		// Get Categories for posts.
		$categories_list = get_the_category_list( $separate_meta );

		echo '<div class="entry-meta">';

		echo '<span class="byline"><i class="fa fa-user"></i>';
		echo '<span class="screen-reader-text">' . esc_html__( 'by', 'martian' ) . '</span>';
		echo '<span class="author vcard">' . get_the_author_posts_link() . '</span>';
		echo '</span>';

		// We don't want to output .entry-footer if it will be empty, so make sure its not.
		if ( ( martian_categorized_blog() && $categories_list ) || get_edit_post_link() ) {


			if ( 'post' === get_post_type() ) {
				if ( $categories_list && martian_categorized_blog() ) {

					// Make sure there's more than one category before displaying.
					if ( $categories_list && martian_categorized_blog() ) {
						echo '<span class="cat-links"><i class="fa fa-tags"></i><span class="screen-reader-text">' . __( 'Categories', 'martian' ) . '</span>' . $categories_list . '</span>';
					}
				}
			}

		}

		if ( comments_open() ) {
			echo '<span class="comments"><i class="fa fa-comments-o"></i>';
			comments_popup_link();
			echo '</span>';
		}

		martian_edit_link();

		echo '</div> <!-- .entry-meta -->';
	}
endif;

if ( ! function_exists( 'martian_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function martian_entry_footer() {

		/* translators: used between list items, there is a space after the comma */
		$separate_meta = __( ', ', 'martian' );

		// Get Tags for posts.
		$tags_list = get_the_tag_list( '', $separate_meta );

		// We don't want to output .entry-footer if it will be empty, so make sure its not.
		if ( $tags_list || get_edit_post_link() ) {

			echo '<footer class="entry-footer">';

			if ( 'post' === get_post_type() ) {
				if ( $tags_list ) {
					echo '<span class="cat-tags-links">';
					echo '<span class="tags-links"><i class="fa fa-hashtag"></i><span class="screen-reader-text">' . __( 'Tags', 'martian' ) . '</span>' . $tags_list . '</span>';
					echo '</span>';
				}
			}

			martian_edit_link();

			echo '</footer> <!-- .entry-footer -->';
		}
	}
endif;


if ( ! function_exists( 'martian_edit_link' ) ) :
	/**
	 * Returns an accessibility-friendly link to edit a post or page.
	 *
	 * This also gives us a little context about what exactly we're editing
	 * (post or page?) so that users understand a bit more where they are in terms
	 * of the template hierarchy and their content. Helpful when/if the single-page
	 * layout with multiple posts/pages shown gets confusing.
	 */
	function martian_edit_link() {

		edit_post_link(
			sprintf(
			/* translators: %s: Name of current post */
				__( 'Edit<span class="screen-reader-text"> "%s"</span>', 'martian' ),
				get_the_title()
			),
			'<span class="edit-link"><i class="fa fa-pencil"></i>',
			'</span>'
		);
	}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function martian_categorized_blog() {
	$category_count = get_transient( 'martian_categories' );

	if ( false === $category_count ) {
		// Create an array of all the categories that are attached to posts.
		$categories = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$category_count = count( $categories );

		set_transient( 'martian_categories', $category_count );
	}

	return $category_count > 1;
}


/**
 * Flush out the transients used in martian_categorized_blog.
 */
function martian_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'martian_categories' );
}

add_action( 'edit_category', 'martian_category_transient_flusher' );
add_action( 'save_post', 'martian_category_transient_flusher' );
